@@ -1618,6 +1618,9 @@ class Update(MethodsInterface):
     def create_binhost_data(self):
         dv = self.clVars
         last_ts = dv.Get('cl_update_last_timestamp')
+        if not dv.Get('update.cl_update_binhost') and not dv.Get('update.cl_update_binhost_choice'):
+            dv.Write('cl_update_binhost_set', "off")
+            dv.Set('cl_update_binhost_set', 'off')
         if (not dv.Get('update.cl_update_binhost_choice') and not dv.GetBool('update.cl_update_binhost_set')) \
                 or dv.Get('update.cl_update_binhost_choice') == 'auto':
             if dv.Get('cl_update_binhost_stable_opt_set'):
