@@ -1316,9 +1316,7 @@ class VariableClUpdateProfileSystem(Variable):
             try:
                 if (not dv.Get('cl_update_rep_name') or
                         not dv.Get('cl_update_rep_url')):
-                    raise VariableError(
-                        _("Repository variables "
-                          "were not configured for the profile"))
+                    return True
                 if not dv.Get('os_linux_name'):
                     raise VariableError("")
                 if repo_name not in list(dv.Get('cl_update_rep_name')):
